==> nhc98_1.16.orig.tar.gz: nhc98-1.16/src/prelude/BinArray/GetUBAFree.z.c <==
#include "newmacros.h"
#include "runtime.h"

#define FN_NHC_46BinArray_46hs_95getUBAFree_35	((void*)startLabel+8)
#define CT_v179	((void*)startLabel+36)
#define F0_NHC_46BinArray_46hs_95getUBAFree_35	((void*)startLabel+44)
#define FN_NHC_46BinArray_46hs_95getUBAFree	((void*)startLabel+56)
#define CT_v181	((void*)startLabel+80)
#define CF_NHC_46BinArray_46hs_95getUBAFree	((void*)startLabel+88)
#define CT_v183	((void*)startLabel+136)
#define ST_v182	((void*)startLabel+152)
#define ST_v180	((void*)startLabel+176)
#define ST_v178	((void*)startLabel+203)
extern Node TM_NHC_46BinArray[];
void FR_NHC_46BinArray_46hs_95getUBAFree_35(void);
extern Node TM_NHC_46BinArray[];
extern Node FN_NHC_46Internal_46_95mkIOok1[];
extern Node TM_NHC_46BinArray[];

static Node startLabel[] = {
  bytes2word(1,0,0,1)
, useLabel(CT_v179)
,	/* FN_NHC_46BinArray_46hs_95getUBAFree_35: (byte 0) */
  useLabel(TM_NHC_46BinArray)
, bytes2word(PUSH_ARG_I1,EVAL,POP_I1,PRIMITIVE)
, useLabel(FR_NHC_46BinArray_46hs_95getUBAFree_35)
, bytes2word(RETURN_EVAL,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, 90022
, useLabel(ST_v178)
,	/* CT_v179: (byte 0) */
  HW(0,1)
, 0
,	/* F0_NHC_46BinArray_46hs_95getUBAFree_35: (byte 0) */
  CAPTAG(useLabel(FN_NHC_46BinArray_46hs_95getUBAFree_35),1)
, bytes2word(0,0,0,0)
, useLabel(CT_v181)
,	/* FN_NHC_46BinArray_46hs_95getUBAFree: (byte 0) */
  useLabel(TM_NHC_46BinArray)
, bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_I3,HEAP_CVAL_I4)
, bytes2word(RETURN_EVAL,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, 90022
, useLabel(ST_v180)
,	/* CT_v181: (byte 0) */
  HW(2,0)
, 0
,	/* CF_NHC_46BinArray_46hs_95getUBAFree: (byte 0) */
  VAPTAG(useLabel(FN_NHC_46BinArray_46hs_95getUBAFree))
, VAPTAG(useLabel(FN_NHC_46Internal_46_95mkIOok1))
, useLabel(F0_NHC_46BinArray_46hs_95getUBAFree_35)
, bytes2word(1,0,0,1)
, useLabel(CT_v183)
,};
Node FN_NHC_46BinArray_46getUBAFree[] = {
  useLabel(TM_NHC_46BinArray)
, bytes2word(NEEDHEAP_I32,PUSH_ARG_I1,PUSH_HEAP,HEAP_CVAL_I3)
, bytes2word(ZAP_ARG_I1,EVAL,NEEDHEAP_I32,APPLY)
, bytes2word(1,RETURN_EVAL,ENDCODE,0)
, bytes2word(0,0,0,0)
, 120001
, useLabel(ST_v182)
,	/* CT_v183: (byte 0) */
  HW(1,1)
, 0
,};
Node F0_NHC_46BinArray_46getUBAFree[] = {
  CAPTAG(useLabel(FN_NHC_46BinArray_46getUBAFree),1)
, VAPTAG(useLabel(FN_NHC_46BinArray_46hs_95getUBAFree))
,	/* ST_v182: (byte 0) */
  bytes2word(78,72,67,46)
, bytes2word(66,105,110,65)
, bytes2word(114,114,97,121)
, bytes2word(46,103,101,116)
, bytes2word(85,66,65,70)
,	/* ST_v180: (byte 4) */
  bytes2word(114,101,101,0)
, bytes2word(78,72,67,46)
, bytes2word(66,105,110,65)
, bytes2word(114,114,97,121)
, bytes2word(46,104,115,95)
, bytes2word(103,101,116,85)
, bytes2word(66,65,70,114)
,	/* ST_v178: (byte 3) */
  bytes2word(101,101,0,78)
, bytes2word(72,67,46,66)
, bytes2word(105,110,65,114)
, bytes2word(114,97,121,46)
, bytes2word(104,115,95,103)
, bytes2word(101,116,85,66)
, bytes2word(65,70,114,101)
, bytes2word(101,35,0,0)
,};

#include <haskell2c.h>
#include <HsFFI.h>

/* foreign import ccall "hs_getUBAFree" NHC.BinArray.hs_getUBAFree# 1 :: FFI.ForeignObj -> Prelude.Int */
extern HsInt hs_getUBAFree(void*);
#ifdef PROFILE
static SInfo pf_hs_getUBAFree = {"NHC.BinArray","NHC.BinArray.hs_getUBAFree#","Prelude.Int"};
#endif
C_HEADER(FR_NHC_46BinArray_46hs_95getUBAFree_35) {
  NodePtr nodeptr;
  HsInt result;
  void* arg1;
  nodeptr = C_GETARG1(1);
  IND_REMOVE(nodeptr);
  arg1 = (void*)derefForeignObj((ForeignObj*)GET_INT_VALUE(nodeptr));

  result = hs_getUBAFree(arg1);

  nodeptr = nhc_mkInt(result);
  INIT_PROFINFO(nodeptr,&pf_hs_getUBAFree);
  C_RETURN(nodeptr);
}

==> nhc98_1.18.orig.tar.gz: nhc98-1.18/src/prelude/BinArray/GetUBAFree.z.c <==
#include "newmacros.h"
#include "runtime.h"

#define FN_NHC_46BinArray_46hs_95getUBAFree_35	((void*)startLabel+8)
#define CT_v183	((void*)startLabel+36)
#define F0_NHC_46BinArray_46hs_95getUBAFree_35	((void*)startLabel+44)
#define FN_NHC_46BinArray_46hs_95getUBAFree	((void*)startLabel+56)
#define CT_v185	((void*)startLabel+80)
#define CF_NHC_46BinArray_46hs_95getUBAFree	((void*)startLabel+88)
#define CT_v187	((void*)startLabel+136)
#define ST_v186	((void*)startLabel+152)
#define ST_v184	((void*)startLabel+176)
#define ST_v182	((void*)startLabel+203)
extern Node TM_NHC_46BinArray[];
void FR_NHC_46BinArray_46hs_95getUBAFree_35(void);
extern Node FN_NHC_46Internal_46_95mkIOok1[];

static Node startLabel[] = {
  bytes2word(1,0,0,1)
, useLabel(CT_v183)
,	/* FN_NHC_46BinArray_46hs_95getUBAFree_35: (byte 0) */
  useLabel(TM_NHC_46BinArray)
, bytes2word(PUSH_ARG_I1,EVAL,POP_I1,PRIMITIVE)
, useLabel(FR_NHC_46BinArray_46hs_95getUBAFree_35)
, bytes2word(RETURN_EVAL,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, 90001
, useLabel(ST_v182)
,	/* CT_v183: (byte 0) */
  HW(0,1)
, 0
,	/* F0_NHC_46BinArray_46hs_95getUBAFree_35: (byte 0) */
  CAPTAG(useLabel(FN_NHC_46BinArray_46hs_95getUBAFree_35),1)
, bytes2word(0,0,0,0)
, useLabel(CT_v185)
,	/* FN_NHC_46BinArray_46hs_95getUBAFree: (byte 0) */
  useLabel(TM_NHC_46BinArray)
, bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_I3,HEAP_CVAL_I4)
, bytes2word(RETURN_EVAL,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, 90001
, useLabel(ST_v184)
,	/* CT_v185: (byte 0) */
  HW(2,0)
, 0
,	/* CF_NHC_46BinArray_46hs_95getUBAFree: (byte 0) */
  VAPTAG(useLabel(FN_NHC_46BinArray_46hs_95getUBAFree))
, VAPTAG(useLabel(FN_NHC_46Internal_46_95mkIOok1))
, useLabel(F0_NHC_46BinArray_46hs_95getUBAFree_35)
, bytes2word(1,0,0,1)
, useLabel(CT_v187)
,};
Node FN_NHC_46BinArray_46getUBAFree[] = {
  useLabel(TM_NHC_46BinArray)
, bytes2word(NEEDHEAP_I32,PUSH_ARG_I1,PUSH_HEAP,HEAP_CVAL_I3)
, bytes2word(ZAP_ARG_I1,EVAL,NEEDHEAP_I32,APPLY)
, bytes2word(1,RETURN_EVAL,ENDCODE,0)
, bytes2word(0,0,0,0)
, 120001
, useLabel(ST_v186)
,	/* CT_v187: (byte 0) */
  HW(1,1)
, 0
,};
Node F0_NHC_46BinArray_46getUBAFree[] = {
  CAPTAG(useLabel(FN_NHC_46BinArray_46getUBAFree),1)
, VAPTAG(useLabel(FN_NHC_46BinArray_46hs_95getUBAFree))
,	/* ST_v186: (byte 0) */
  bytes2word(78,72,67,46)
, bytes2word(66,105,110,65)
, bytes2word(114,114,97,121)
, bytes2word(46,103,101,116)
, bytes2word(85,66,65,70)
,	/* ST_v184: (byte 4) */
  bytes2word(114,101,101,0)
, bytes2word(78,72,67,46)
, bytes2word(66,105,110,65)
, bytes2word(114,114,97,121)
, bytes2word(46,104,115,95)
, bytes2word(103,101,116,85)
, bytes2word(66,65,70,114)
,	/* ST_v182: (byte 3) */
  bytes2word(101,101,0,78)
, bytes2word(72,67,46,66)
, bytes2word(105,110,65,114)
, bytes2word(114,97,121,46)
, bytes2word(104,115,95,103)
, bytes2word(101,116,85,66)
, bytes2word(65,70,114,101)
, bytes2word(101,35,0,0)
,};

#include <haskell2c.h>
#include <HsFFI.h>

/* foreign import ccall "hs_getUBAFree" NHC.BinArray.hs_getUBAFree# 1 :: FFI.ForeignObj -> Prelude.Int */
extern HsInt hs_getUBAFree(void*);
#ifdef PROFILE
static SInfo pf_NHC_46BinArray_46hs_95getUBAFree_35 = {"NHC.BinArray","NHC.BinArray.hs_getUBAFree#","Prelude.Int"};
#endif
C_HEADER(FR_NHC_46BinArray_46hs_95getUBAFree_35) {
  NodePtr nodeptr;
  HsInt result;
  void* arg1;
  nodeptr = C_GETARG1(1);
  IND_REMOVE(nodeptr);
  arg1 = (void*)derefForeignObj((ForeignObj*)GET_INT_VALUE(nodeptr));

  result = hs_getUBAFree(arg1);

  nodeptr = nhc_mkInt(result);
  INIT_PROFINFO(nodeptr,&pf_NHC_46BinArray_46hs_95getUBAFree_35);
  C_RETURN(nodeptr);
}
